@@ -1,4 +1,4 @@
-# $rcs = ' $Id: Test.pm,v 2.285 2008/11/29 01:55:09 Martin Exp $ ' ;
+# $rcs = ' $Id: Test.pm,v 2.289 2013/03/25 15:13:57 martin Exp $ ' ;
 
 =head1 NAME
 
@@ -54,7 +54,7 @@ use vars qw( @EXPORT );
 
 use vars qw( $VERSION $bogus_query $websearch );
 
-$VERSION = do { my @r = (q$Revision: 2.285 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 2.289 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $bogus_query = "Bogus" . $$ . "NoSuchWord" . time;
 
 ($MODE_DUMMY, $MODE_INTERNAL, $MODE_EXTERNAL, $MODE_UPDATE) = qw(dummy internal external update);
@@ -813,7 +813,7 @@ sub test_most_results
   my %hioExemplar;
   my %hiiFailed;
   # Create a bit vector large enough to hold one bit for each test:
-  my $oV = new Bit::Vector($iCount-1);
+  my $oV = new Bit::Vector($iCount);
   # Turn on all the bits (we will turn off bits when tests fail):
   $oV->Fill;
   my $iVall = $oV->to_Dec;
@@ -829,6 +829,10 @@ sub test_most_results
       {
       $sCode = "(\$oResult->$sField =~ m!$sValue!)";
       } # if
+    elsif ($sCmp eq 'unlike')
+      {
+      $sCode = "(\$oResult->$sField !~ m!$sValue!)";
+      } # if
     elsif ($sCmp eq 'date')
       {
       $sCode = "((ParseDate(\$oResult->$sField) || '') ne q{})";
@@ -849,7 +853,7 @@ ENDCODE
     } # foreach TEST
   $sCodeAll .= "1;\n";
   # $sCodeAll =~ s{/\(\?-xism:}{/(}g;
-  print STDERR " DDD the test is ==$sCodeAll==\n";
+  # print STDERR " DDD the test is ==$sCodeAll==\n";
  RESULT:
   foreach my $oResult ($oSearch->results())
     {
@@ -870,7 +874,7 @@ ENDCODE
       $iAnyFailed++;
       } # if
     } # foreach RESULT
-  ok($iResult, 'got some results');
+  ok($iResult, qq{got more than zero results ($iResult, to be exact)});
   if ($iAnyFailed)
     {
     Test::More::diag(" Here are result(s) that exemplify test failure(s):");
@@ -882,7 +886,7 @@ ENDCODE
   while (my ($sItem, $iFailed) = each %hiiFailed)
     {
     my $fPctFailed = ($iFailed / $iResult);
-    ok((1 - $fPct) < $fPctFailed, sprintf(qq{%0.3f%% of %s tests failed}, $fPctFailed * 100, $sItem));
+    ok($fPctFailed < (1 - $fPct), sprintf(qq{%0.1f%% of %s tests failed}, $fPctFailed * 100, $sItem));
     } # while
   } # test_most_results
 
